// Copyright (c) Mito
import React, { useState, useRef } from 'react';
import SheetTabActions from './SheetTabActions';
// import icons
import SelectedSheetTabDropdownIcon from '../icons/SelectedSheetTabDropdownIcon';
import UnselectedSheetTabDropdownIcon from '../icons/UnselectedSheetTabDropdownIcon';
import { classNames } from '../../utils/classNames';
import Input from '../elements/Input';
/*
    Component that displays a dataframe name at the bottom of the sheet, and
    furthermore renders the sheet actions if the sheet action dropdown is
    clicked.
*/
export default function SheetTab(props) {
    // We only set this as open if it the currOpenSheetTabActions
    const displayActions = props.currOpenSheetTabActions === props.sheetIndex;
    const [isRename, setIsRename] = useState(false);
    const [newDataframeName, setNewDataframeName] = useState(props.dfName);
    const isSelectedTab = props.selectedSheetIndex === props.sheetIndex;
    const selectedClass = isSelectedTab ? 'tab-selected' : '';
    const elRef = useRef(null);
    /*
        Helper function that determines how much we should shift the SheetTabActions over.

        To do so, we find the bounding box of the Mito container as well as the tab itself.
        The bounding box can be understood as the left, right, top and bottom pixel indexes
        of the div element itself.

        We return the difference between the left edge of the mito container as well as the
        tab. However, we cap this at 1, so that the SheetTabActions must be displayed within
        the Mito container.
    */
    function getLeftShift() {
        var _a, _b, _c, _d;
        const containerRectLeft = (_b = (_a = elRef.current) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect()) === null || _b === void 0 ? void 0 : _b.left;
        const tabRectLeft = (_d = (_c = props.mitoContainerRef) === null || _c === void 0 ? void 0 : _c.getBoundingClientRect()) === null || _d === void 0 ? void 0 : _d.left;
        if (containerRectLeft !== undefined && tabRectLeft !== undefined) {
            return Math.max(containerRectLeft - tabRectLeft, 1);
        }
        return 0;
    }
    const onRename = async () => {
        await props.mitoAPI.sendDataframeRenameEdit(props.sheetIndex, newDataframeName);
        props.setCurrOpenSheetTabActions(undefined);
        setIsRename(false);
    };
    const toggleSheetTabActions = () => {
        props.closeOpenEditingPopups();
        if (displayActions) {
            props.setCurrOpenSheetTabActions(undefined);
        }
        else {
            props.setCurrOpenSheetTabActions(props.sheetIndex);
        }
    };
    return (React.createElement("div", { ref: elRef, className: classNames('tab', selectedClass), onClick: () => {
            props.setSelectedSheetIndex(props.sheetIndex);
        }, onDoubleClick: () => { setIsRename(true); } },
        React.createElement("div", { className: 'tab-content' },
            isRename &&
                React.createElement("form", { onSubmit: async (e) => { e.preventDefault(); await onRename(); }, onBlur: onRename },
                    React.createElement(Input, { value: newDataframeName, onChange: (e) => { setNewDataframeName(e.target.value); }, autoFocus: true })),
            !isRename &&
                React.createElement("p", { className: 'tab-sheet-name' }, props.dfName),
            React.createElement("div", { className: 'sheet-tab-dropdown-button-div', onClick: toggleSheetTabActions }, isSelectedTab ? React.createElement(SelectedSheetTabDropdownIcon, null) : React.createElement(UnselectedSheetTabDropdownIcon, null))),
        displayActions &&
            React.createElement(SheetTabActions, { setCurrOpenSheetTabActions: props.setCurrOpenSheetTabActions, setSelectedSheetIndex: props.setSelectedSheetIndex, setIsRename: setIsRename, dfName: props.dfName, selectedSheetIndex: props.selectedSheetIndex, sheetIndex: props.sheetIndex, getLeftShift: getLeftShift, mitoAPI: props.mitoAPI })));
}
//# sourceMappingURL=SheetTab.js.map