// Copyright (c) Mito
import React, { useState, Fragment } from 'react';
import { ModalEnum } from '../Mito';
import DefaultModal from '../DefaultModal';
// import css
import "../../../css/save-analysis-modal.css";
import TextButton from '../elements/TextButton';
import Input from '../elements/Input';
import { classNames } from '../../utils/classNames';
// A set of characters we don't allow in analysis names,
// just to avoid file name issues
// Taken from: https://www.mtu.edu/umc/services/digital/writing/characters-avoid/
const ILLEGAL_FILENAME_CHARACTERS = [
    '#',
    '%',
    '&',
    '{', '}',
    '/', '\\',
    '<', '>',
    '*',
    '?',
    '$',
    '!',
    '\'', '"',
    ':',
    '@'
];
function getAnalysisNameError(analysisName) {
    /*
        Helper function for validating named analyses. Avoids a set of illegal characters.

        Returns the empty string if there is no error.
    */
    if (analysisName.length == 0) {
        return 'Please enter a name for your analysis';
    }
    for (let i = 0; i < ILLEGAL_FILENAME_CHARACTERS.length; i++) {
        if (analysisName.indexOf(ILLEGAL_FILENAME_CHARACTERS[i]) > -1) {
            return `Invalid analysis name. Please remove the "${ILLEGAL_FILENAME_CHARACTERS[i]}"`;
        }
    }
    return '';
}
/*
  A modal that allows a user to save an analysis with the input
  name.
*/
const SaveAnalysis = (props) => {
    const [saveAnalysisName, setSaveAnalysisName] = useState(props.saveAnalysisName !== undefined ? props.saveAnalysisName : '');
    const [analysisNameError, setAnalysisNameError] = useState('');
    const clickSave = async () => {
        // Don't let the user submit if they have an invalid analysis name!
        if (getAnalysisNameError(saveAnalysisName) !== '') {
            setAnalysisNameError(`Please fix before saving: ${getAnalysisNameError(saveAnalysisName)}`);
            return;
        }
        if (props.savedAnalysisNames.indexOf(saveAnalysisName) > -1) {
            // If user is overwriting an analysis, we display a popup to let them know. 
            props.setModal({
                type: ModalEnum.SaveAnalysisOverwrite,
                saveAnalysisName: saveAnalysisName
            });
        }
        else {
            // Otherwise, we just log and save the analysis
            await props.mitoAPI.sendSaveAnalysisMessage(saveAnalysisName);
            props.setModal({ type: ModalEnum.None });
        }
    };
    const onChangeAnalysisName = (newAnalysisName) => {
        setSaveAnalysisName(newAnalysisName);
        setAnalysisNameError(getAnalysisNameError(newAnalysisName));
    };
    return (React.createElement(DefaultModal, { header: `Save your current analysis`, modalType: ModalEnum.SaveAnalysis, viewComponent: React.createElement(Fragment, null,
            React.createElement("div", { className: classNames('save-analysis-label', 'header-3') }, "Name your analysis"),
            React.createElement(Input, { placeholder: 'Monthly Sales Analysis', value: saveAnalysisName, onChange: (e) => onChangeAnalysisName(e.target.value), autoFocus: true }),
            analysisNameError !== '' &&
                React.createElement("p", { className: 'save-analysis-name-error' }, analysisNameError),
            React.createElement("div", { className: 'mt-2 save-analysis-analysis-selection-container' },
                React.createElement("div", { className: classNames('save-analysis-label', 'header-3') }, "Existing analyses"),
                React.createElement("div", { className: 'save-analysis-analysis-selection' },
                    props.savedAnalysisNames.length == 0 &&
                        React.createElement("p", null, "Save an analysis to have it appear here."),
                    props.savedAnalysisNames.map((savedAnalysisName) => {
                        return (React.createElement("div", { className: 'save-analysis-analysis-name', key: savedAnalysisName, onClick: () => { onChangeAnalysisName(savedAnalysisName); } }, savedAnalysisName));
                    })))), buttons: React.createElement(Fragment, null,
            React.createElement(TextButton, { variant: 'light', width: 'small', onClick: () => { props.setModal({ type: ModalEnum.None }); } }, "Close"),
            React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: clickSave }, "Save")) }));
};
export default SaveAnalysis;
//# sourceMappingURL=SaveAnalysisModal.js.map