// Copyright (c) Mito
import React, { useEffect, useState } from 'react';
import SmallSelect, { SelectSize, TitleColor } from '../../elements/SmallSelect';
import XIcon from '../../icons/XIcon';
import { GraphType } from './GraphSidebar';
import '../../../../css/graph-sidebar/axis-section.css';
import Select from '../../elements/Select';
export var GraphAxisType;
(function (GraphAxisType) {
    GraphAxisType["X_AXIS"] = "X axis";
    GraphAxisType["Y_AXIS"] = "Y axis";
})(GraphAxisType || (GraphAxisType = {}));
/*
    The Axis Section contains all of the fields needed to manipulate the selected
    column headers for each axis of the graph.
*/
const AxisSection = (props) => {
    /*
        Save the cta for each of the possible subtexts. We save a subtext for each one
        so that changing one cta does not change all of them.
    */
    const [disableDueToSingleAxisGraphCTA, setDisableDueToSingleAxisGraphCTA] = useState(undefined);
    const [disabledDueToKeySeriesRequirementCTA, setDisabledDueToKeySeriesCTARequirementCTA] = useState(undefined);
    const [disabledDueToMaxSeriesReachedCTA, setDisabledDueToMaxSeriesReachedCTA] = useState(undefined);
    useEffect(() => {
        if (disableDueToSingleAxisGraphCTA !== undefined) {
            logCtaClick('Single Axis Graph');
        }
    }, [disableDueToSingleAxisGraphCTA]);
    useEffect(() => {
        if (disabledDueToKeySeriesRequirementCTA !== undefined) {
            logCtaClick('Key Series Required');
        }
    }, [disabledDueToKeySeriesRequirementCTA]);
    useEffect(() => {
        if (disabledDueToMaxSeriesReachedCTA !== undefined) {
            logCtaClick('Max Series Reached');
        }
    }, [disabledDueToMaxSeriesReachedCTA]);
    const logCtaClick = (ctaClicked) => {
        const x_axis_column_headers = props.graphAxis === GraphAxisType.X_AXIS ? props.selectedColumnHeaders : props.otherAxisSelectedColumnHeaders;
        const y_axis_column_headers = props.graphAxis === GraphAxisType.Y_AXIS ? props.selectedColumnHeaders : props.otherAxisSelectedColumnHeaders;
        void props.mitoAPI.sendLogMessage('graph_cta_clicked', {
            'graph_type': props.graphType,
            'axis': props.graphAxis,
            'x_axis_column_headers': x_axis_column_headers,
            'y_axis_column_headers': y_axis_column_headers,
            'cta_clicked': ctaClicked
        });
    };
    // Filter the column headers that the user can select to only the columns that are the correct type for the graph
    let selectableColumnHeaders = [];
    if (props.graphType === GraphType.BOX || props.graphType === GraphType.HISTOGRAM) {
        selectableColumnHeaders = props.columnHeaders.filter(columnHeader => {
            return props.columnMitoTypes[columnHeader] === 'number_series';
        });
    }
    else {
        // If the graph is not a Box plot of Histogram, then any column can be selected.
        selectableColumnHeaders = props.columnHeaders;
    }
    // Create Large Selects and delete buttons for each of the columns that have already been selected
    const selectedColumnHeaderSelects = props.selectedColumnHeaders.map((selectedColumnHeader, i) => {
        return ((React.createElement("div", { className: 'axis-section-selected-column-header-large-select-div', 
            /* Add a key because we're constructing a list of html elements */
            key: selectedColumnHeader },
            React.createElement(Select, { value: selectedColumnHeader, options: selectableColumnHeaders, onChange: (columnHeader) => {
                    props.updateAxisData(props.graphAxis, i, columnHeader);
                }, width: 'small' }),
            React.createElement("div", { className: 'axis-section-selected-column-header-large-select-x-icon', onClick: () => {
                    props.updateAxisData(props.graphAxis, i);
                } },
                React.createElement(XIcon, null)))));
    });
    // Calculate if the axis should be disabled for any of the following three reasons. 
    const selectedColumnHeaderLength = props.selectedColumnHeaders.length;
    const otherAxisSelectedColumnHeaders = props.otherAxisSelectedColumnHeaders.length;
    /*
        1. If the graph type selected only supports one axis, and the other axis already has a series,
        then don't let the user add a series to this axis
    */
    const disableDueToSingleAxisGraphBool = (props.graphType === GraphType.BOX || props.graphType === GraphType.HISTOGRAM) &&
        props.otherAxisSelectedColumnHeaders.length > 0;
    /*
        2. If the axis only has 1 series, but the other axis has more than 1 series, then you can't add more series
        to this axis because we don't let users stack on both columns.
    */
    const disabledDueToKeySeriesRequirementBool = selectedColumnHeaderLength === 1 && otherAxisSelectedColumnHeaders > 1;
    /* 3. If there are already four series being graphed, then don't let the user add another series */
    const disabledDueToMaxSeriesReachedBool = selectedColumnHeaderLength + otherAxisSelectedColumnHeaders >= 4;
    return (React.createElement("div", { className: 'axis-section-container' },
        React.createElement("div", { className: 'axis-section-header-div' },
            React.createElement("div", { className: 'graph-sidebar-toolbar-section-title' }, props.graphAxis),
            React.createElement(SmallSelect, { startingValue: 'add', optionsArray: selectableColumnHeaders, setValue: (columnHeader) => {
                    props.updateAxisData(props.graphAxis, props.selectedColumnHeaders.length, columnHeader);
                }, titleColor: TitleColor.BLUE, selectSize: SelectSize.EXTRA_SMALL_SELECT, disabled: disableDueToSingleAxisGraphBool || disabledDueToKeySeriesRequirementBool || disabledDueToMaxSeriesReachedBool })),
        disableDueToSingleAxisGraphBool &&
            React.createElement("div", { className: 'graph-sidebar-toolbar-subtext' },
                props.graphType,
                "s only support one axis.\u00A0",
                disableDueToSingleAxisGraphCTA === undefined ?
                    React.createElement("a", { className: 'axis-section-cta', onClick: () => {
                            setDisableDueToSingleAxisGraphCTA("Thanks! Coming Soon. ");
                        } }, "Want to use both axises?") :
                    React.createElement(React.Fragment, null, disableDueToSingleAxisGraphCTA)),
        !disableDueToSingleAxisGraphBool && disabledDueToKeySeriesRequirementBool &&
            React.createElement("div", { className: 'graph-sidebar-toolbar-subtext' },
                "You can only have multiple series on one axis at a time.\u00A0",
                disabledDueToKeySeriesRequirementCTA === undefined ?
                    React.createElement("a", { className: 'axis-section-cta', onClick: () => {
                            setDisabledDueToKeySeriesCTARequirementCTA("Thanks! Coming Soon. ");
                        } }, "Want to stack both axises?") :
                    React.createElement(React.Fragment, null, disabledDueToKeySeriesRequirementCTA)),
        !disableDueToSingleAxisGraphBool && !disabledDueToKeySeriesRequirementBool && disabledDueToMaxSeriesReachedBool &&
            React.createElement("div", { className: 'graph-sidebar-toolbar-subtext' },
                "You can only graph four series at once.\u00A0",
                disabledDueToMaxSeriesReachedCTA === undefined ?
                    React.createElement("a", { className: 'axis-section-cta', onClick: () => {
                            setDisabledDueToMaxSeriesReachedCTA("Thanks! Coming Soon. ");
                        } }, "Want more?") :
                    React.createElement(React.Fragment, null, disabledDueToMaxSeriesReachedCTA)),
        selectedColumnHeaderSelects));
};
export default AxisSection;
//# sourceMappingURL=AxisSection.js.map